VlcMediaInfo class
Metadata and discovered track information for the current media.
Values are best-effort and depend on what VLC can discover from the current container, stream, and platform backend.
Constructors
-
VlcMediaInfo({String? title, String? artist, String? album, Duration duration = Duration.zero, List<
VlcMediaTrackInfo> videoTracks = const <VlcMediaTrackInfo>[], List<VlcMediaTrackInfo> audioTracks = const <VlcMediaTrackInfo>[], List<VlcMediaTrackInfo> subtitleTracks = const <VlcMediaTrackInfo>[]}) -
Creates media information.
const
-
VlcMediaInfo.fromMap(Map<
Object?, Object?> map) -
Creates media information from a native platform map.
factory
Properties
- album → String?
-
Media album when available.
final
- artist → String?
-
Media artist when available.
final
-
audioTracks
→ List<
VlcMediaTrackInfo> -
Audio tracks discovered in the current media.
final
- duration → Duration
-
Media duration reported by VLC, or Duration.zero when unknown.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subtitleTracks
→ List<
VlcMediaTrackInfo> -
Subtitle tracks discovered in the current media.
final
- title → String?
-
Media title when available.
final
-
videoTracks
→ List<
VlcMediaTrackInfo> -
Video tracks discovered in the current media.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override