VlcPlaybackState enum
Playback lifecycle states reported by the native VLC player.
Values
- idle → const VlcPlaybackState
-
No media is loaded.
- opening → const VlcPlaybackState
-
VLC is opening the current media.
- buffering → const VlcPlaybackState
-
VLC is buffering enough data to continue playback.
- playing → const VlcPlaybackState
-
Media is currently playing.
- paused → const VlcPlaybackState
-
Media playback is paused.
- stopped → const VlcPlaybackState
-
Playback has been stopped.
- ended → const VlcPlaybackState
-
The current media reached the end.
- error → const VlcPlaybackState
-
The player is in an error state.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VlcPlaybackState> - A constant List of the values in this enum, in order of their declaration.